# PharmacoDI

![GitHub Actions Workflow](https://github.com/bhklab/PharmacoDI/workflows/Python%package/badge.svg)

The PharmacoDI Python package contains all the functions needed to make the PharmacoDB database tables from a collection of .csv for each PSet.

## Description

This package is intended for internal use by members of the BHK Lab. 
It automates the process of generating the database tables for our PharmacoDB web app.

## Installation

To install this package with pip run:
`pip install git+https://github.com/bhklab/PharmacoDI#egg=PharmacoDI`
